# AuthenticationProviderElement

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | [optional] 
**identity_type** | **str** |  | [optional] 
**forms_login_enabled** | **bool** |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 
**javascript_links** | **list[str]** |  | [optional] 
**css_links** | **list[str]** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


